==> cionuke-0.7.0rc1-py2.py3-none-any.whl: cionuke/widgets/notice_grp.py <==
import os
from PySide2 import QtWidgets, QtCore, QtGui
from cionuke.const import PLUGIN_DIR
import webbrowser

STYLESHEET = """
QFrame {{ border: none; margin: none; padding:none;}}
"""


class NoticeGrp(QtWidgets.QFrame):

    def __init__(self, text, severity="info", url=None):
        super(NoticeGrp, self).__init__()

        self.url = url
        if severity not in ["info", "warning", "error", "success"]:
            severity = "error"

        self.scale_factor = self.logicalDpiX() / 96.0
        icon_size = 24 if self.logicalDpiX() < 150 else 48

        self.setFrameStyle(QtWidgets.QFrame.Panel | QtWidgets.QFrame.Sunken)
        self.setLineWidth(2)

        layout = QtWidgets.QHBoxLayout()
        self.setLayout(layout)

        layout.setMargin(0)
        layout.setSpacing(0)

        icon_filename = "Conductor{0}_{1}x{1}.png".format(
            severity.capitalize(), icon_size)
        iconPath = os.path.join(
            PLUGIN_DIR, 'icons', icon_filename)

        img_label = QtWidgets.QLabel(self)
        pixmap = QtGui.QPixmap(iconPath)
        img_label.setPixmap(pixmap)
        img_label.setAlignment(QtCore.Qt.AlignHCenter | QtCore.Qt.AlignVCenter)
        img_label.setFixedWidth(40 * self.scale_factor)
        layout.addWidget(img_label)

        if self.url:
            widget = QtWidgets.QPushButton(text)
            widget.setAutoDefault(False)
            widget.clicked.connect(self.on_click)
        else:
            widget = QtWidgets.QLabel()
            widget.setMargin(10)
            widget.setWordWrap(True)
            widget.setText(text)

        layout.addWidget(widget)
        self.setStyleSheet(STYLESHEET)

    def on_click(self):
        webbrowser.open(self.url)

==> cionuke-0.8.0-py2.py3-none-any.whl: cionuke/widgets/notice_grp.py <==
import os
import webbrowser

from cionuke import const as k
from cionuke import QtWidgets, QtCore, QtGui

STYLESHEET = """
QFrame {{ border: none; margin: none; padding:none;}}
"""


class NoticeGrp(QtWidgets.QFrame):

    def __init__(self, text, severity="info", url=None):
        super(NoticeGrp, self).__init__()

        self.url = url
        if severity not in ["info", "warning", "error", "success"]:
            severity = "error"

        self.scale_factor = self.logicalDpiX() / 96.0
        icon_size = 24 if self.logicalDpiX() < 150 else 48

        self.setFrameStyle(QtWidgets.QFrame.Panel | QtWidgets.QFrame.Sunken)
        self.setLineWidth(2)

        layout = QtWidgets.QHBoxLayout()
        self.setLayout(layout)

        layout.setContentsMargins(0, 0, 0, 0)
        layout.setSpacing(0)

        icon_filename = "Conductor{0}_{1}x{1}.png".format(
            severity.capitalize(), icon_size)
        iconPath = os.path.join(
            k.PLUGIN_DIR, 'icons', icon_filename)

        img_label = QtWidgets.QLabel(self)
        pixmap = QtGui.QPixmap(iconPath)
        img_label.setPixmap(pixmap)
        img_label.setAlignment(QtCore.Qt.AlignHCenter | QtCore.Qt.AlignVCenter)
        img_label.setFixedWidth(40 * self.scale_factor)
        layout.addWidget(img_label)

        if self.url:
            widget = QtWidgets.QPushButton(text)
            widget.setAutoDefault(False)
            widget.clicked.connect(self.on_click)
        else:
            widget = QtWidgets.QLabel()
            widget.setMargin(10)
            widget.setWordWrap(True)
            widget.setText(text)

        layout.addWidget(widget)
        self.setStyleSheet(STYLESHEET)

    def on_click(self):
        webbrowser.open(self.url)
